<template>
  <div class="app-container">
    <el-form :model="searchForm" :inline="true">
      <el-form-item label="客户名称">
        <el-input
          v-model="searchForm.searchText"
          placeholder="输入客户名称搜索"
          @change="handleQuery"
          clearable
          :prefix-icon="Search"
        />
      </el-form-item>
      <el-form-item label="合同号">
        <el-input
          v-model="searchForm.customerContractNo"
          placeholder="输入合同号"
          @change="handleQuery"
          clearable
          :prefix-icon="Search"
        />
      </el-form-item>
      <el-form-item label="项目名称">
        <el-input
          v-model="searchForm.projectName"
          placeholder="输入项目名称"
          @change="handleQuery"
          clearable
          :prefix-icon="Search"
        />
      </el-form-item>
      <el-form-item label="回款日期">
        <el-date-picker
          v-model="searchForm.receiptPaymentDate"
          value-format="YYYY-MM-DD"
          format="YYYY-MM-DD"
          type="daterange"
          start-placeholder="开始时间"
          end-placeholder="结束时间"
          clearable
          style="width: 300px"
          @change="changeDateRange"
          @clear="clearRange"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" @click="handleQuery"> 搜索 </el-button>
      </el-form-item>
    </el-form>
    <div class="table_list">
      <PIMTable
        rowKey="id"
        :column="tableColumn"
        :tableData="tableData"
        :page="page"
        :isSelection="true"
        :isShowSummary="isShowSummarySon"
        :summaryMethod="summarizeMainTable1"
        :tableLoading="tableLoading"
        :total="total"
        @pagination="pagination"
        @selection-change="handleSelectionChange"
      ></PIMTable>
    </div>
  </div>
</template>

<script setup>
import { ref } from "vue";
import { Search } from "@element-plus/icons-vue";
import { receiptPaymentHistoryListPage } from "@/api/salesManagement/receiptPayment.js";
import useFormData from "@/hooks/useFormData";
import dayjs from "dayjs";

const { proxy } = getCurrentInstance();
const tableColumn = ref([
  {
    label: "回款日期",
    prop: "receiptPaymentDate",
  },
  {
    label: "客户名称",
    prop: "customerName",
  },
  {
    label: "项目名称",
    prop: "projectName",
  },
  {
    label: "合同号",
    prop: "customerContractNo",
  },
  {
    label: "项目名称",
    prop: "projectName",
  },
  {
    label: "回款金额（元）",
    prop: "receiptPaymentAmount",
    formatData: (params) => {
      return params ? parseFloat(params).toFixed(2) : 0;
    },
  },
  {
    label: "回款方式",
    prop: "receiptPaymentType",
    dataType: "tag",
    formatData: (params) => {
      if (params == 0) {
        return "电汇";
      } else if (params == 1) {
        return "承兑";
      } else {
        return null;
      }
    },
    formatType: (params) => {
      return "info";
    },
  },
  {
    label: "登记人",
    prop: "registrant",
  },
  {
    label: "登记日期",
    prop: "createTime",
  },
]);
const tableData = ref([]);
const selectedRows = ref([]);
const tableLoading = ref(false);
const page = reactive({
  current: 1,
  size: 100,
});
const total = ref(0);

const { form: searchForm } = useFormData({
  searchText: undefined,
  receiptPaymentDate: [
    dayjs().startOf("month").format("YYYY-MM-DD"),
    dayjs().endOf("month").format("YYYY-MM-DD"),
  ],
  receiptPaymentDateStart: dayjs()
    .startOf("month")
    .format("YYYY-MM-DD 00:00:00"),
  receiptPaymentDateEnd: dayjs().endOf("month").format("YYYY-MM-DD 23:59:59"),
  customerContractNo: undefined,
  projectName: undefined,
});
const { receipt_payment_type } = proxy.useDict("receipt_payment_type");
const isShowSummarySon = ref(true);
// 查询列表
/** 搜索按钮操作 */
const handleQuery = () => {
  page.current = 1;
  getList();
};
const pagination = (obj) => {
  page.current = obj.page;
  page.size = obj.limit;
  getList();
};
const getList = () => {
  tableLoading.value = true;
  const { receiptPaymentDate, ...rest } = searchForm;
  receiptPaymentHistoryListPage({ ...rest, ...page }).then((res) => {
    tableLoading.value = false;
    tableData.value = res.records;
    total.value = res.total;
  });
};
// 子表合计方法
const summarizeMainTable1 = (param) => {
  return proxy.summarizeTable(param, ["receiptPaymentAmount"], {
    ticketsNum: { noDecimal: true }, // 不保留小数
    futureTickets: { noDecimal: true }, // 不保留小数
  });
};
// 表格选择数据
const handleSelectionChange = (selection) => {
  selectedRows.value = selection;
};

const changeDateRange = (date) => {
  if (date) {
    searchForm.receiptPaymentDateStart = dayjs(date[0]).format(
      "YYYY-MM-DD 00:00:00"
    );
    searchForm.receiptPaymentDateEnd = dayjs(date[1]).format(
      "YYYY-MM-DD 23:59:59"
    );
    getList();
  }
};

const clearRange = () => {
  searchForm.receiptPaymentDate = [];
  searchForm.receiptPaymentDateStart = undefined;
  searchForm.receiptPaymentDateEnd = undefined;
  getList();
};

onMounted(() => {
  getList();
});
</script>

<style scoped lang="scss">
.table_list {
  margin-top: unset;
}
</style>
